/// <reference types="node" />
import { KeyObject } from "crypto";
import { generateP256Keys, loadP256PrivateKey, loadP256PublicKey, convertP256PublicKeyToRaw } from "./utils/P256";
import { generateEd25519Keys, loadEd25519PrivateKey, loadEd25519PublicKey, convertEd25519PublicKeyToRaw } from "./utils/Ed25519";
import { generateX25519Keys, loadX25519PrivateKey, loadX25519PublicKey, convertX25519PublicKeyToRaw } from "./utils/X25519";
declare function signMessage(message: string | Buffer, privateKey: KeyObject): Promise<string>;
declare function verifySignature(message: string | Buffer, signature: string | Buffer, publicKey: KeyObject): Promise<boolean>;
declare function encryptWithSymmetricKey(message: string, privateKey: KeyObject, publicKey: KeyObject): Promise<{
    message: string;
    symmetricKeySalt: string;
}>;
declare function decryptWithSymmetricKey(encryptedMessage: string | Buffer, privateKey: KeyObject, publicKey: KeyObject, symmetricKeySalt: string | Buffer): Promise<string>;
export declare const P256: {
    generateKeys: typeof generateP256Keys;
    loadPrivateKey: typeof loadP256PrivateKey;
    loadPublicKey: typeof loadP256PublicKey;
    formatPublicKeyToRaw: typeof convertP256PublicKeyToRaw;
    sign: typeof signMessage;
    verify: typeof verifySignature;
    encrypt: typeof encryptWithSymmetricKey;
    decrypt: typeof decryptWithSymmetricKey;
};
export declare const Ed25519: {
    generateKeys: typeof generateEd25519Keys;
    loadPrivateKey: typeof loadEd25519PrivateKey;
    loadPublicKey: typeof loadEd25519PublicKey;
    formatPublicKeyToRaw: typeof convertEd25519PublicKeyToRaw;
    sign: typeof signMessage;
    verify: typeof verifySignature;
};
export declare const X25519: {
    generateKeys: typeof generateX25519Keys;
    loadPrivateKey: typeof loadX25519PrivateKey;
    loadPublicKey: typeof loadX25519PublicKey;
    formatPublicKeyToRaw: typeof convertX25519PublicKeyToRaw;
    encrypt: typeof encryptWithSymmetricKey;
    decrypt: typeof decryptWithSymmetricKey;
};
declare const cryptokit: {
    P256: {
        generateKeys: typeof generateP256Keys;
        loadPrivateKey: typeof loadP256PrivateKey;
        loadPublicKey: typeof loadP256PublicKey;
        formatPublicKeyToRaw: typeof convertP256PublicKeyToRaw;
        sign: typeof signMessage;
        verify: typeof verifySignature;
        encrypt: typeof encryptWithSymmetricKey;
        decrypt: typeof decryptWithSymmetricKey;
    };
    Ed25519: {
        generateKeys: typeof generateEd25519Keys;
        loadPrivateKey: typeof loadEd25519PrivateKey;
        loadPublicKey: typeof loadEd25519PublicKey;
        formatPublicKeyToRaw: typeof convertEd25519PublicKeyToRaw;
        sign: typeof signMessage;
        verify: typeof verifySignature;
    };
    X25519: {
        generateKeys: typeof generateX25519Keys;
        loadPrivateKey: typeof loadX25519PrivateKey;
        loadPublicKey: typeof loadX25519PublicKey;
        formatPublicKeyToRaw: typeof convertX25519PublicKeyToRaw;
        encrypt: typeof encryptWithSymmetricKey;
        decrypt: typeof decryptWithSymmetricKey;
    };
};
export default cryptokit;
